Changes
=======

1.2.0 (2025-08-06)
------------------

- Fix window scaling

1.1.0 (2025-07-05)
------------------

- Now does not depend on idlelib
- Added more adaptation optimizations
- Port to pyproject.toml build system

1.0.0 (2024-10-05)
------------------

- Initial release
